5 CTXD Data Types
====================

With the introduction of new data types that are not specified in the original specifications, it is necessary to define these types along with their attributes, base type, and eventually the conformance clauses. In this section, each new data type is defined, and for some, a use case example is provided.

The list of data types is no more maintained as part of the profile definition. Please
refer to the inline `documentation <https://otupy.readthedocs.io/en/latest/_autosummary/otupy.profiles.ctxd.data.html#module-otupy.profiles.ctxd.data>`__.

